Table of Featurizers — matminer 0.6.3 documentation

# Table of Featurizers

Below, you will find a description of each featurizer, listed in tables grouped by module.

## bandstructure

### Features derived from a material’s electronic bandstructure.

(matminer.featurizers.bandstructure)

Name | Description
--- | ---
`BranchPointEnergy` | Branch point energy and absolute band edge position.
`BandFeaturizer` | Featurizes a pymatgen band structure object.

## base

### Parent classes and meta-featurizers.

(matminer.featurizers.base)

Name | Description
--- | ---
`MultipleFeaturizer` | Class to run multiple featurizers on the same input data.
`StackedFeaturizer` | Use the output of a machine learning model as features
`BaseFeaturizer` | Abstract class to calculate features from raw materials input data

## composition

### Features based on a material’s composition.

(matminer.featurizers.composition)

Name | Description
--- | ---
`ElementProperty` | Class to calculate elemental property attributes.
`Meredig` | Class to calculate features as defined in Meredig et. al.
`OxidationStates` | Statistics about the oxidation states for each specie.
`AtomicOrbitals` | Determine HOMO/LUMO features based on a composition.
`BandCenter` | Estimation of absolute position of band center using electronegativity.
`ElectronegativityDiff` | Features from electronegativity differences between anions and cations.
`ElectronAffinity` | Calculate average electron affinity times formal charge of anion elements.
`Stoichiometry` | Calculate norms of stoichiometric attributes.
`ValenceOrbital` | Attributes of valence orbital shells
`IonProperty` | Ionic property attributes. Similar to ElementProperty.
`ElementFraction` | Class to calculate the atomic fraction of each element in a composition.
`TMetalFraction` | Class to calculate fraction of magnetic transition metals in a composition.
`CohesiveEnergy` | Cohesive energy per atom using elemental cohesive energies and
`CohesiveEnergyMP` | Cohesive energy per atom lookup using Materials Project
`Miedema` | Formation enthalpies of intermetallic compounds, from Miedema et al.
`YangSolidSolution` | Mixing thermochemistry and size mismatch terms of Yang and Zhang (2012)
`AtomicPackingEfficiency` | Packing efficiency based on a geometric theory of the amorphous packing

## conversions

### Conversion utilities.

(matminer.featurizers.conversions)

Name | Description
--- | ---
`ConversionFeaturizer` | Abstract class to perform data conversions.
`StrToComposition` | Utility featurizer to convert a string to a Composition
`StructureToComposition` | Utility featurizer to convert a Structure to a Composition.
`StructureToIStructure` | Utility featurizer to convert a Structure to an immutable IStructure.
`DictToObject` | Utility featurizer to decode a dict to Python object via MSON.
`JsonToObject` | Utility featurizer to decode json data to a Python object via MSON.
`StructureToOxidStructure` | Utility featurizer to add oxidation states to a pymatgen Structure.
`CompositionToOxidComposition` | Utility featurizer to add oxidation states to a pymatgen Composition.
`CompositionToStructureFromMP` | Featurizer to get a Structure object from Materials Project using the

## dos

### Features based on a material’s electronic density of states.

(matminer.featurizers.dos)

Name | Description
--- | ---
`SiteDOS` | report the fractional s/p/d/f dos for a particular site. a CompleteDos
`DOSFeaturizer` | Significant character and contribution of the density of state from a
`DopingFermi` | The fermi level (w.r.t. selected reference energy) associated with a
`Hybridization` | quantify s/p/d/f orbital character and their hybridizations at band edges
`DosAsymmetry` | Quantifies the asymmetry of the DOS near the Fermi level.

## function

### Classes for expanding sets of features calculated with other featurizers.

(matminer.featurizers.function)

Name | Description
--- | ---
`FunctionFeaturizer` | Features from functions applied to existing features, e.g. “1/x”

## site

### Features from individual sites in a material’s crystal structure.

(matminer.featurizers.site)

Name | Description
--- | ---
`AGNIFingerprints` | Product integral of RDF and Gaussian window function, from Botu et al.
`OPSiteFingerprint` | Local structure order parameters computed from a site’s neighbor env.
`CrystalNNFingerprint` | A local order parameter fingerprint for periodic crystals.
`VoronoiFingerprint` | Voronoi tessellation-based features around target site.
`IntersticeDistribution` | Interstice distribution in the neighboring cluster around an atom site.
`ChemicalSRO` | Chemical short range ordering, deviation of local site and nominal structure compositions
`GaussianSymmFunc` | Gaussian symmetry function features suggested by Behler et al.
`EwaldSiteEnergy` | Compute site energy from Coulombic interactions
`ChemEnvSiteFingerprint` | Resemblance of given sites to ideal environments
`CoordinationNumber` | Number of first nearest neighbors of a site.
`GeneralizedRadialDistributionFunction` | Compute the general radial distribution function (GRDF) for a site.
`AngularFourierSeries` | Compute the angular Fourier series (AFS), including both angular and radial info
`LocalPropertyDifference` | Differences in elemental properties between site and its neighboring sites.
`BondOrientationalParameter` | Averages of spherical harmonics of local neighbors
`SiteElementalProperty` | Elemental properties of atom on a certain site
`AverageBondLength` | Determines the average bond length between one specific site
`AverageBondAngle` | Determines the average bond angles of a specific site with

## structure

### Generating features based on a material’s crystal structure.

(matminer.featurizers.structure)

Name | Description
--- | ---
`DensityFeatures` | Calculates density and density-like features
`GlobalSymmetryFeatures` | Determines symmetry features, e.g. spacegroup number and crystal system
`Dimensionality` | Returns dimensionality of structure: 1 means linear chains of atoms OR
`RadialDistributionFunction` | Calculate the radial distribution function (RDF) of a crystal structure.
`PartialRadialDistributionFunction` | Compute the partial radial distribution function (PRDF) of an xtal structure
`ElectronicRadialDistributionFunction` | Calculate the inherent electronic radial distribution function (ReDF)
`CoulombMatrix` | The Coulomb matrix, a representation of nuclear coulombic interaction.
`SineCoulombMatrix` | A variant of the Coulomb matrix developed for periodic crystals.
`OrbitalFieldMatrix` | Representation based on the valence shell electrons of neighboring atoms.
`MinimumRelativeDistances` | Determines the relative distance of each site to its closest neighbor.
`SiteStatsFingerprint` | Computes statistics of properties across all sites in a structure.
`EwaldEnergy` | Compute the energy from Coulombic interactions.
`BondFractions` | Compute the fraction of each bond in a structure, based on NearestNeighbors.
`BagofBonds` | Compute a Bag of Bonds vector, as first described by Hansen et al. (2015).
`StructuralHeterogeneity` | Variance in the bond lengths and atomic volumes in a structure
`MaximumPackingEfficiency` | Maximum possible packing efficiency of this structure
`ChemicalOrdering` | How much the ordering of species in the structure differs from random
`StructureComposition` | Features related to the composition of a structure
`XRDPowderPattern` | 1D array representing powder diffraction of a structure as calculated by
`CGCNNFeaturizer` | Features generated by training a Crystal Graph Convolutional Neural Network
`JarvisCFID` | Classical Force-Field Inspired Descriptors (CFID) from Jarvis-ML.
`SOAP` | Smooth overlap of atomic positions (interface via dscribe).
`GlobalInstabilityIndex` | The global instability index of a structure.
`StructuralComplexity` | Shannon information entropy of a structure.